## Code for performing model selection as done in Griesser et al. Fine-scale
## kin recognition in the absence in the absence of social cues in the 
## Siberian jay, a monogamous bird species

## Szymon M. Drobniak
## Last updated: 15/09/30

## (1) read in data to form a data.m (males) and data.f (females) objects



## (2) prepare data

# factorise relevant variables
data.f$ring <- as.factor(data.f$ring)
data.m$ring <- as.factor(data.m$ring)
data.f$year <- as.factor(data.f$year)
data.m$year <- as.factor(data.m$year)

# form predictor vectors and subset data
# last three elements are the three best R estimators
my_predictors.m <- c("ring","breeder_ring","year","NSI","prop_um","displaced","chased","groupsize","sex",
                     "age","kinship","submissive","breeder_age ","DyadML","Ritland")
                     my_predictors.f <- c("ring","breeder_ring","year","NSI","prop_um","displaced","chased","groupsize","sex",
                     "age","kinship","submissive","breeder_age ","DyadML","Ritland")
                     data.m[,my_predictors.m] -> data.m
                     data.f[,my_predictors.f] -> data.f
                     
                     # subset to only non-kin individuals
                     data.m <- gdata::drop.levels(subset(data.m, kinship=="nk"))
                     data.f <- gdata::drop.levels(subset(data.f, kinship=="nk"))
                     
                     
                     
                     ## (3) load relevant packages (install if not available in your R distribution)
                     
                     library(MuMIn)
                     library(glmmADMB)
                     
                     
                     
                     ## (4.1) run glmmADMB models for each R estimator
                     ## (4.2) run the dredge function to obtain model list for each R estimator
                     
            
                     # DyadML
                     model.m.2zipnk <- glmmadmb(chased~DyadML+prop_um+age+breeder_age +groupsize+sex+submissive+
                     DyadML:breeder_age +breeder_age :submissive+year, random=~1|breeder_ring+1|ring, data=data.m, zeroInflation=T)
                     model.f.2zipnk <- glmmadmb(chased~TrioML+prop_um+age+breeder_age +groupsize+sex+submissive+
                     DyadML:breeder_age +breeder_age :submissive+year, random=~1|breeder_ring+1|ring, data=data.f, zeroInflation=T)
                     model.m.2zipnk.dr <- dredge(model.m.2zipnk, trace=T, fixed=c("sex"))
                     model.f.2zipnk.dr <- dredge(model.f.2zipnk, trace=T, fixed=c("sex"))
                     
                     # Ritland
                     model.m.3zipnk <- glmmadmb(chased~Ritland+prop_um+age+breeder_age +groupsize+sex+submissive+
                     Ritland:breeder_age +breeder_age :submissive+year, random=~1|breeder_ring+1|ring, data=data.m, zeroInflation=T)
                     model.f.3zipnk <- glmmadmb(chased~Ritland+prop_um+age+breeder_age +groupsize+sex+submissive+
                     Ritland:breeder_age +breeder_age :submissive+year, random=~1|breeder_ring+1|ring, data=data.f, zeroInflation=T)
                     model.m.3zipnk.dr <- dredge(model.m.3zipnk, trace=T, fixed=c("sex"))
                     model.f.3zipnk.dr <- dredge(model.f.3zipnk, trace=T, fixed=c("sex"))
                     
                     
                     
                     ## (5) for each model list perform model averaging
                     ## and generate model selection table
                     ## e.g. for DyadML in males
                     
                     # model selection table with the first 20 models
                     head(model.m.2zipnk.dr, 20) 
                     # model-averaged estimates for models within deltaAIC<=2
                     summary(model.avg(model.m.2zipnk.dr, subset=delta<=2))
                     